==> ui-18.0.1.tgz: package/components/table/Cell.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isNumber, isUndefined } from 'lodash';
import React, { useEffect, useRef } from 'react';
import { getClassName } from '@react-devui/utils';
import { useContextRequired } from '../../hooks';
import { usePrefixConfig } from '../root';
import { DTableContext } from './Table';
const ZINDEX_CONFIG = {
    top: 5,
    right: 1,
    bottom: 5,
    left: 1,
};
export function DCell(props) {
    const { children, dTag, dWidth, dFixed, dAlign, dEllipsis } = props, restProps = __rest(props, ["children", "dTag", "dWidth", "dFixed", "dAlign", "dEllipsis"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gFixed, gEllipsis } = useContextRequired(DTableContext);
    //#endregion
    //#region Ref
    const cellRef = useRef(null);
    //#endregion
    const ellipsis = gEllipsis || dEllipsis;
    let fixedLeft = false;
    let fixedRight = false;
    let fixedStyle = {};
    if (dFixed) {
        fixedStyle = Object.assign(Object.assign({}, dFixed), { position: 'sticky', zIndex: Object.keys(dFixed).reduce((previous, current) => previous + ZINDEX_CONFIG[current], 0) });
        if ('left' in dFixed) {
            fixedLeft = true;
        }
        if ('right' in dFixed) {
            fixedRight = true;
        }
    }
    useEffect(() => {
        if (cellRef.current && cellRef.current.parentElement) {
            let showShadow = false;
            if (fixedLeft && gFixed.includes('left')) {
                const elsL = cellRef.current.parentElement.querySelectorAll(`.${dPrefix}table__cell--fixed-left`);
                if (elsL.item(elsL.length - 1) === cellRef.current) {
                    showShadow = true;
                }
            }
            if (fixedRight && gFixed.includes('right')) {
                const elsR = cellRef.current.parentElement.querySelectorAll(`.${dPrefix}table__cell--fixed-right`);
                if (elsR.item(0) === cellRef.current) {
                    showShadow = true;
                }
            }
            cellRef.current.classList.toggle(`${dPrefix}table__cell--fixed-shadow`, showShadow);
        }
    });
    return React.createElement(dTag, Object.assign(Object.assign({}, restProps), { ref: cellRef, className: getClassName(restProps.className, `${dPrefix}table__cell`, `${dPrefix}table__cell--${dAlign}`, {
            [`${dPrefix}table__cell--fixed-left`]: fixedLeft,
            [`${dPrefix}table__cell--fixed-right`]: fixedRight,
            [`${dPrefix}table__cell--ellipsis`]: ellipsis,
        }), style: Object.assign(Object.assign(Object.assign({}, restProps.style), fixedStyle), { width: isUndefined(dWidth) ? undefined : dWidth }) }), _jsx("div", Object.assign({ className: `${dPrefix}table__cell-content`, style: {
            width: isUndefined(dWidth)
                ? undefined
                : `calc(${dWidth + (isNumber(dWidth) ? 'px' : '')} - var(--${dPrefix}table-padding-size) * 2)`,
        } }, { children: children })));
}

==> ui-18.3.1.tgz: package/components/table/Cell.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isNumber, isUndefined } from 'lodash';
import React, { useEffect, useRef } from 'react';
import { getClassName } from '@react-devui/utils';
import { useContextRequired } from '../../hooks';
import { usePrefixConfig } from '../root';
import { DTableContext } from './Table';
const ZINDEX_CONFIG = {
    top: 5,
    right: 1,
    bottom: 5,
    left: 1,
};
export function DCell(props) {
    const { children, dTag, dWidth, dFixed, dAlign, dEllipsis, dNowrap } = props, restProps = __rest(props, ["children", "dTag", "dWidth", "dFixed", "dAlign", "dEllipsis", "dNowrap"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gFixed, gEllipsis } = useContextRequired(DTableContext);
    //#endregion
    //#region Ref
    const cellRef = useRef(null);
    //#endregion
    const ellipsis = gEllipsis || dEllipsis;
    let fixedLeft = false;
    let fixedRight = false;
    let fixedStyle = {};
    if (dFixed) {
        fixedStyle = Object.assign(Object.assign({}, dFixed), { position: 'sticky', zIndex: Object.keys(dFixed).reduce((previous, current) => previous + ZINDEX_CONFIG[current], 0) });
        if ('left' in dFixed) {
            fixedLeft = true;
        }
        if ('right' in dFixed) {
            fixedRight = true;
        }
    }
    useEffect(() => {
        if (cellRef.current && cellRef.current.parentElement) {
            let showShadow = false;
            if (fixedLeft && gFixed.includes('left')) {
                const elsL = cellRef.current.parentElement.querySelectorAll(`.${dPrefix}table__cell--fixed-left`);
                if (elsL.item(elsL.length - 1) === cellRef.current) {
                    showShadow = true;
                }
            }
            if (fixedRight && gFixed.includes('right')) {
                const elsR = cellRef.current.parentElement.querySelectorAll(`.${dPrefix}table__cell--fixed-right`);
                if (elsR.item(0) === cellRef.current) {
                    showShadow = true;
                }
            }
            cellRef.current.classList.toggle(`${dPrefix}table__cell--fixed-shadow`, showShadow);
        }
    });
    return React.createElement(dTag, Object.assign(Object.assign({}, restProps), { ref: cellRef, className: getClassName(restProps.className, `${dPrefix}table__cell`, `${dPrefix}table__cell--${dAlign}`, {
            [`${dPrefix}table__cell--fixed-left`]: fixedLeft,
            [`${dPrefix}table__cell--fixed-right`]: fixedRight,
            [`${dPrefix}table__cell--ellipsis`]: ellipsis,
            [`${dPrefix}table__cell--nowrap`]: dNowrap,
        }), style: Object.assign(Object.assign(Object.assign({}, restProps.style), fixedStyle), { width: isUndefined(dWidth) ? undefined : dWidth }) }), _jsx("div", Object.assign({ className: `${dPrefix}table__cell-content`, style: {
            width: isUndefined(dWidth)
                ? undefined
                : `calc(${dWidth + (isNumber(dWidth) ? 'px' : '')} - var(--${dPrefix}table-padding-size) * 2)`,
        } }, { children: children })));
}
